@@ -77,7 +77,9 @@ processDocument <- function(taskId = NULL, language="English",
 
   process_details <- abbyy_GET("processDocument", query = querylist, ...)
 
-  resdf <- ldply(process_details, rbind)
+  resdf <- ldply(process_details, rbind, .id = NULL)
+  row.names(resdf) <- NULL
+  resdf[] <- lapply(resdf, as.character)
 
   # Print some important things
   cat("Status of the task: ", resdf$status, "\n")
